django-subdomains
=================

Subdomain helpers for the Django framework, including subdomain-based URL
routing and reversing.

Full documentation can be found here: http://django-subdomains.readthedocs.org/

Build Status
------------

.. image:: https://travis-ci.org/messense/django-subdomains.svg?branch=master
   :target: http://travis-ci.org/messense/django-subdomains

Tested on Python 2.6, 2.7, 3.3 and 3.4, as well as Django 1.5, 1.6, 1.7, and 1.8.
